//
//  ViewController.m
//  TestApp
//
//  Created by mac on 29.01.13.
//  Copyright (c) 2013 mac. All rights reserved.
//

#import "ViewController.h"
#import "UIImageView+AFNetworking.h"

@interface ViewController ()

@end

@implementation ViewController
@synthesize adTableView;
@synthesize adSearchBar, filteredAds;
@synthesize photos;

- (void)viewDidLoad
{
    [super viewDidLoad];
    currentPage = 0;
    filteredAds = [[NSMutableArray alloc]init];
    photos = [[NSArray alloc]init];
    
    xmlParser = [[XMLParser alloc]init];
    xmlParser = [xmlParser loadXMLFromURL:[self urlWithPageNumber:currentPage]];
	// Do any additional setup after loading the view, typically from a nib.
}

//returns url with certain page
-(NSString*)urlWithPageNumber:(NSInteger)page{
    NSString* urlString = [NSString stringWithFormat:@"http://commonservice.dmir.ru/webservices/Announcements.asmx/SearchAnnouncementsByDaysAgo?rubricId=dmir_737&locationId=1&DaysAgo=&pageNum=%d&pageSize=25",page];
    return urlString;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Check to see whether the normal table or search results table is being displayed and return the count from the appropriate array
    if (tableView == self.searchDisplayController.searchResultsTableView) {
        return [filteredAds count];
    } else {
        return [[xmlParser ads] count];
    }
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"CustomCell";
    CustomCell *cell = (CustomCell*)[tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (cell == nil) {
        NSArray *nib = [[NSBundle mainBundle] loadNibNamed:@"CustomCell" owner:self options:nil];
        cell = [nib objectAtIndex:0];
    }
    Announcement* ad = nil;
    
    if (tableView == self.searchDisplayController.searchResultsTableView){
        ad = [filteredAds objectAtIndex:indexPath.row];
    }
    else{
        ad = [xmlParser.ads objectAtIndex:indexPath.row];
    }
    
    //add image to cell with AFNetworking
    //NSData * imageData = [[NSData alloc] initWithContentsOfURL: [NSURL URLWithString: ad.titleImage]];
    //cell.cellImage.image = [UIImage imageWithData:imageData];
    [cell.cellImage setImageWithURL:[NSURL URLWithString:ad.titleImage]placeholderImage:[UIImage imageNamed:@"image-placeholder.png"]];

    //add name label to cell
    cell.nameLabel.text = ad.name;
    
    //add price to cell
    cell.priceLabel.text = ad.price;
    
    UIImage *background = [UIImage imageNamed:@"cell_bg.png"];
    UIImageView *cellBackgroundView = [[UIImageView alloc] initWithImage:background];
    cellBackgroundView.image = background;
    cell.backgroundView = cellBackgroundView;
    
    return cell;
}

//hight of cells in tableview
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
	return 86;
}

//detect the bottom and add new data
-(void)scrollViewDidScroll:(UIScrollView *)scrollView{
    if(scrollView.contentOffset.y >= (scrollView.contentSize.height - scrollView.bounds.size.height) && [filteredAds count]==0) {

        //load the next page
        currentPage+=1;
        xmlParser = [xmlParser loadXMLFromURL:[self urlWithPageNumber:currentPage]];
        
        [adTableView reloadData];
    }
}

#pragma mark Content Filtering
-(void)filterContentForSearchText:(NSString*)searchText scope:(NSString*)scope {
    // Update the filtered array based on the search text and scope.
    // Remove all objects from the filtered search array
    [self.filteredAds removeAllObjects];
    // Filter the array using NSPredicate
    NSPredicate *predicate = [NSPredicate predicateWithFormat:@"SELF.name contains[c] %@",searchText];
    filteredAds = [NSMutableArray arrayWithArray:[[xmlParser ads] filteredArrayUsingPredicate:predicate]];
}

#pragma mark - UISearchDisplayController Delegate Methods

- (BOOL)searchDisplayController:(UISearchDisplayController *)controller shouldReloadTableForSearchString:(NSString *)searchString
{
    // Tells the table data source to reload when text changes
    [self filterContentForSearchText:searchString scope:
     [[self.searchDisplayController.searchBar scopeButtonTitles] objectAtIndex:[self.searchDisplayController.searchBar selectedScopeButtonIndex]]];
    
    // Return YES to cause the search result table view to be reloaded.
    return YES;
}

- (BOOL)searchDisplayController:(UISearchDisplayController *)controller shouldReloadTableForSearchScope:(NSInteger)searchOption
{
    // Tells the table data source to reload when scope bar selection changes
    [self filterContentForSearchText:[self.searchDisplayController.searchBar text] scope:
     [[self.searchDisplayController.searchBar scopeButtonTitles] objectAtIndex:searchOption]];
    
    // Return YES to cause the search result table view to be reloaded.
    return YES;
}

//activates searching when tap search button
- (IBAction)searchBtn:(id)sender {
    [adSearchBar becomeFirstResponder];
}

//open image viewer on taping the cell
-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    //we need to fill this array with images of selected dog
    NSMutableArray* images = [[NSMutableArray alloc]init];
    
    //in case of filtering we get data from filteredAds
    NSMutableArray* donorArray = [[NSMutableArray alloc]init];
    if([filteredAds count]==0)
        donorArray = [NSMutableArray arrayWithArray:xmlParser.ads];
    else donorArray = [NSMutableArray arrayWithArray:filteredAds];
    //NSLog(@"%d",[filteredAds count]);
    for(int i=0;i<[[[xmlParser.ads objectAtIndex:indexPath.row] imageArray] count];i++){

        [images addObject:[MWPhoto photoWithURL:[NSURL URLWithString:[[[donorArray objectAtIndex:indexPath.row] imageArray] objectAtIndex:i]]]];
        [[images objectAtIndex:i] setCaption:[[donorArray objectAtIndex:indexPath.row]description]];
    }
    self.photos = images;
    MWPhotoBrowser *browser = [[MWPhotoBrowser alloc] initWithDelegate:self];
    
    [self.navigationController pushViewController:browser animated:YES];
    
    // Deselect cell
	[tableView deselectRowAtIndexPath:indexPath animated:YES];
}

#pragma mark - MWPhotoBrowserDelegate
//count of detailed photos
- (NSUInteger)numberOfPhotosInPhotoBrowser:(MWPhotoBrowser *)photoBrowser {
    return [photos count];
}

//insert photos to viewer from array
- (MWPhoto *)photoBrowser:(MWPhotoBrowser *)photoBrowser photoAtIndex:(NSUInteger)index {
    if (index < [photos count])
        return [photos objectAtIndex:index];
    return nil;
}

//add description text for detailed view
- (MWCaptionView *)photoBrowser:(MWPhotoBrowser *)photoBrowser captionViewForPhotoAtIndex:(NSUInteger)index {
        MWPhoto *photo = [self.photos objectAtIndex:index];
        MWCaptionView *captionView = [[MWCaptionView alloc] initWithPhoto:photo];
        return captionView;
    }
@end

